def penjumalah(a, b):
    try
        return a + b
    except
        return None

def pengurangan(a, b):
    try
        return a - b
    except
        return None

def perkalian(a, b):
    try
        return a *
    except
        return None

def pembagian(a, b)
    try
        return a / b
    except ValueError:
        return None
    except ZeroDivisionError
        return 0